pub(crate) trait HasParent {
type Parent;
// Required method
fn as_parent(&self) -> &Self::Parent;
}Required Associated Types
Required Methods
Implementations on Foreign Types
Sourceimpl<D> HasParent for GPUAdapter<D>where
D: DomTypes,
impl<D> HasParent for GPUAdapter<D>where
D: DomTypes,
Sourceimpl<D> HasParent for GPUAdapterInfo<D>where
D: DomTypes,
impl<D> HasParent for GPUAdapterInfo<D>where
D: DomTypes,
Sourceimpl<D> HasParent for GPUBindGroup<D>where
D: DomTypes,
impl<D> HasParent for GPUBindGroup<D>where
D: DomTypes,
Sourceimpl<D> HasParent for GPUBindGroupLayout<D>where
D: DomTypes,
impl<D> HasParent for GPUBindGroupLayout<D>where
D: DomTypes,
Sourceimpl<D> HasParent for GPUBufferUsage<D>where
D: DomTypes,
impl<D> HasParent for GPUBufferUsage<D>where
D: DomTypes,
Sourceimpl<D> HasParent for GPUColorWrite<D>where
D: DomTypes,
impl<D> HasParent for GPUColorWrite<D>where
D: DomTypes,
Sourceimpl<D> HasParent for GPUCommandBuffer<D>where
D: DomTypes,
impl<D> HasParent for GPUCommandBuffer<D>where
D: DomTypes,
Sourceimpl<D> HasParent for GPUCommandEncoder<D>where
D: DomTypes,
impl<D> HasParent for GPUCommandEncoder<D>where
D: DomTypes,
Sourceimpl<D> HasParent for GPUCompilationInfo<D>where
D: DomTypes,
impl<D> HasParent for GPUCompilationInfo<D>where
D: DomTypes,
Sourceimpl<D> HasParent for GPUCompilationMessage<D>where
D: DomTypes,
impl<D> HasParent for GPUCompilationMessage<D>where
D: DomTypes,
Sourceimpl<D> HasParent for GPUComputePassEncoder<D>where
D: DomTypes,
impl<D> HasParent for GPUComputePassEncoder<D>where
D: DomTypes,
Sourceimpl<D> HasParent for GPUComputePipeline<D>where
D: DomTypes,
impl<D> HasParent for GPUComputePipeline<D>where
D: DomTypes,
Sourceimpl<D> HasParent for GPUDevice<D>where
D: DomTypes,
impl<D> HasParent for GPUDevice<D>where
D: DomTypes,
Sourcefn as_parent(&self) -> &<D as DomTypes>::EventTarget
fn as_parent(&self) -> &<D as DomTypes>::EventTarget
This is used in a type assertion to ensure that the source and webidls agree as to what the parent type is
type Parent = <D as DomTypes>::EventTarget
Sourceimpl<D> HasParent for GPUDeviceLostInfo<D>where
D: DomTypes,
impl<D> HasParent for GPUDeviceLostInfo<D>where
D: DomTypes,
Sourceimpl<D> HasParent for GPUExternalTexture<D>where
D: DomTypes,
impl<D> HasParent for GPUExternalTexture<D>where
D: DomTypes,
Sourceimpl<D> HasParent for GPUInternalError<D>where
D: DomTypes,
impl<D> HasParent for GPUInternalError<D>where
D: DomTypes,
Sourceimpl<D> HasParent for GPUMapMode<D>where
D: DomTypes,
impl<D> HasParent for GPUMapMode<D>where
D: DomTypes,
Sourceimpl<D> HasParent for GPUOutOfMemoryError<D>where
D: DomTypes,
impl<D> HasParent for GPUOutOfMemoryError<D>where
D: DomTypes,
Sourceimpl<D> HasParent for GPUPipelineError<D>where
D: DomTypes,
impl<D> HasParent for GPUPipelineError<D>where
D: DomTypes,
Sourcefn as_parent(&self) -> &<D as DomTypes>::DOMException
fn as_parent(&self) -> &<D as DomTypes>::DOMException
This is used in a type assertion to ensure that the source and webidls agree as to what the parent type is