Trait HasParent
Source pub(crate) trait HasParent {
type Parent;
// Required method
fn as_parent(&self) -> &Self::Parent;
}
This is used in a type assertion to ensure that
the source and webidls agree as to what the parent type is
This is used in a type assertion to ensure that
the source and webidls agree as to what the parent type is
This is used in a type assertion to ensure that
the source and webidls agree as to what the parent type is
This is used in a type assertion to ensure that
the source and webidls agree as to what the parent type is
This is used in a type assertion to ensure that
the source and webidls agree as to what the parent type is
This is used in a type assertion to ensure that
the source and webidls agree as to what the parent type is
This is used in a type assertion to ensure that
the source and webidls agree as to what the parent type is
This is used in a type assertion to ensure that
the source and webidls agree as to what the parent type is
This is used in a type assertion to ensure that
the source and webidls agree as to what the parent type is
This is used in a type assertion to ensure that
the source and webidls agree as to what the parent type is
This is used in a type assertion to ensure that
the source and webidls agree as to what the parent type is
This is used in a type assertion to ensure that
the source and webidls agree as to what the parent type is
This is used in a type assertion to ensure that
the source and webidls agree as to what the parent type is
This is used in a type assertion to ensure that
the source and webidls agree as to what the parent type is